Pos

Struct Pos 

pub struct Pos {
    pub offset: usize,
    pub row: Row,
    pub col: Col,
}
A position in some source code string. Positions save the offset, the row and the column. That means that a position is only valid for a specific source code string.

Fields

offset: usize

Starts at 0.

row: Row

Starts at 1.

col: Col

Starts at 1.

Implementations

Source

impl Pos

pub const fn start() -> Self

Creates a new position at the start of source code.

pub const fn right(self) -> Self

Returns this position, one character to the right.

pub const fn down(self) -> Self

Returns this position, one line down, and with the column reset to 1.